'use strict';

exports.__esModule = true;

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _main = require('../sigma/main');

var _main2 = _interopRequireDefault(_main);

require('../sigma/layout.forceAtlas2');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

/**

ForceAtlas2 component, starts ForceAtlas2 sigma plugin once component is mounted.
It supposes that sigma graph is already in place, therefore component should not be
mounted while graph is unavailable. It can be used within Sigma component if graph is
preloaded, or within loader component, like NeoCypher.

It accepts all the parameters of ForceAtlas2 described on its github page:
@param {boolean} [worker=true]           Use a web worker to run calculations in separate thread
@param {boolean} barnesHutOptimize  Use the algorithm's Barnes-Hut to improve repulsion's scalability
									This is useful for large graph but harmful to small ones.
@param {number} barnesHutTheta
@param {boolean} adjustSizes
@param {number} iterationsPerRender
@param {boolean} [linLogMode=true]
@param {boolean} outboundAttractionDistribution
@param {number} edgeWeightInfluence
@param {number} scalingRatio
@param {boolean} strongGravityMode
@param {number} gravity
@param {number} slowDown
@param {number} timeout   how long algorythm should run. default=graph.nodes().length * 10

[see sigma plugin page for more details](https://github.com/jacomyal/sigma.js/tree/master/plugins/sigma.layout.forceAtlas2)

**/

var ForceAtlas2 = function (_React$Component) {
	(0, _inherits3['default'])(ForceAtlas2, _React$Component);

	function ForceAtlas2(props) {
		(0, _classCallCheck3['default'])(this, ForceAtlas2);

		var _this = (0, _possibleConstructorReturn3['default'])(this, _React$Component.call(this, props));

		_this.render = function () {
			return null;
		};

		_this.state = { running: false };
		return _this;
	}

	ForceAtlas2.prototype.componentDidMount = function componentDidMount() {
		this._refreshGraph();
	};

	ForceAtlas2.prototype.componentDidUpdate = function componentDidUpdate(prevProps, prevState) {
		var s = this.props.sigma;
		if (prevState.running && !this.state.running && s) {
			s.stopForceAtlas2();
			s.settings({ drawEdges: prevState.drawEdges === false ? false : true });
			s.refresh();
		}
	};

	ForceAtlas2.prototype.componentWillUnmount = function componentWillUnmount() {
		if (this.props.sigma) this.props.sigma.killForceAtlas2();
		if (this.state.timer) clearTimeout(this.state.timer);
	};

	//TODO: Add composition of child components after timeout


	ForceAtlas2.prototype._refreshGraph = function _refreshGraph() {
		var _this2 = this;

		var s = this.props.sigma;
		if (!_main2['default'] || !s) return;

		var drawEdges = s.settings("drawEdges");
		if (s.graph.edges().length > 1000) s.settings({ drawEdges: false });

		s.startForceAtlas2(this._stripOptions(this.props));
		// TODO: convert running status to state
		var timer = setTimeout(function () {
			_this2.setState({ running: false, timer: undefined });
		}, this.props.timeout || s.graph.nodes().length * 8);
		this.setState({ running: true, timer: timer, drawEdges: drawEdges });
	};

	//strip force atlas options from component props


	ForceAtlas2.prototype._stripOptions = function _stripOptions(props) {
		return (0, _assign2['default'])({}, props, { sigma: undefined });
	};

	return ForceAtlas2;
}(_react2['default'].Component);

ForceAtlas2.defaultProps = {
	worker: true,
	linLogMode: true
};
ForceAtlas2.propTypes = {
	worker: require('react').PropTypes.bool.isRequired,
	barnesHutOptimize: require('react').PropTypes.bool,
	barnesHutTheta: require('react').PropTypes.number,
	adjustSizes: require('react').PropTypes.bool,
	iterationsPerRender: require('react').PropTypes.number,
	linLogMode: require('react').PropTypes.bool.isRequired,
	outboundAttractionDistribution: require('react').PropTypes.bool,
	edgeWeightInfluence: require('react').PropTypes.number,
	scalingRatio: require('react').PropTypes.number,
	strongGravityMode: require('react').PropTypes.bool,
	slowDown: require('react').PropTypes.number,
	gravity: require('react').PropTypes.number,
	timeout: require('react').PropTypes.number,
	sigma: require('react').PropTypes.any
};
exports['default'] = ForceAtlas2;
module.exports = exports['default'];