'use strict';

exports.__esModule = true;

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _main = require('../sigma/main');

var _main2 = _interopRequireDefault(_main);

require('../sigma/layout.forceLink');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

/**

ForceLink component, starts Force Atlas2 algorythm once component is mounted.
It supposes that sigma graph is already in place, therefore component should not be
mounted while graph is unavailable. It can be used within Sigma component if graph is
preloaded, or within loader component, like NeoCypher.

It accepts all the parameters of ForceLink described on its github page:
@param {boolean} barnesHutOptimize  Use the algorithm's Barnes-Hut to improve repulsion's scalability
									This is useful for large graph but harmful to small ones.
@param {number} barnesHutTheta
@param {boolean} adjustSizes
@param {number} iterationsPerRender
@param {boolean} [linLogMode=true]
@param {boolean} outboundAttractionDistribution
@param {number} edgeWeightInfluence
@param {number} scalingRatio
@param {boolean} strongGravityMode
@param {number} gravity
@param {boolean} alignNodeSiblings
@param {number} nodeSiblingsScale
@param {number} nodeSiblingsAngleMin
@param {boolean} [worker=true]  Use a web worker to run calculations in separate thread
@param {boolean} background
@param {string} easing  Easing mode
@param {"globally"|"locally"} randomize  Randomize node positions before start
@param {number} slowDown
@param {number} timeout   how long algorythm should run. default=graph.nodes().length * 10

[see sigma plugin page for more details](https://github.com/Linkurious/linkurious.js/tree/develop/plugins/sigma.layouts.forceLink)

**/

var ForceLink = function (_React$Component) {
	(0, _inherits3['default'])(ForceLink, _React$Component);

	function ForceLink(props) {
		(0, _classCallCheck3['default'])(this, ForceLink);

		var _this = (0, _possibleConstructorReturn3['default'])(this, _React$Component.call(this, props));

		_this.render = function () {
			return null;
		};

		_this.state = { running: false };
		return _this;
	}

	ForceLink.prototype.componentDidMount = function componentDidMount() {
		this._refreshGraph();
	};

	// Change sigma status only after react rendering complete


	ForceLink.prototype.componentDidUpdate = function componentDidUpdate(prevProps, prevState) {
		var s = this.props.sigma;
		if (prevState.running && !this.state.running && s) {
			this._stopForceLink();
			s.refresh();
		} else if (ForceLink._propsChanged(prevProps, this.props)) {
			this._stopForceLink();
			this._refreshGraph();
		}
	};

	ForceLink.prototype.componentWillUnmount = function componentWillUnmount() {
		this._stopForceLink();
	};

	//TODO: Add composition of child components after timeout


	ForceLink.prototype._stopForceLink = function _stopForceLink() {
		_main2['default'].layouts.stopForceLink();
		if (this.state.timer) clearTimeout(this.state.timer);
		if (this.props.sigma && this.props.sigma.settings) this.props.sigma.settings({ drawEdges: this.state.drawEdges });
	};

	ForceLink.prototype._refreshGraph = function _refreshGraph() {
		var _this2 = this;

		var s = this.props.sigma;
		if (!_main2['default'] || !s) return;

		var drawEdges = s.settings("drawEdges");
		if (s.graph.edges().length > 1000) s.settings({ drawEdges: false });

		_main2['default'].layouts.configForceLink(s, ForceLink._stripOptions(this.props));
		_main2['default'].layouts.startForceLink(s);
		// TODO: convert running status to state
		var timer = setTimeout(function () {
			_this2.setState({ running: false, timer: undefined });
		}, this.props.timeout || s.graph.nodes().length * 8);
		this.setState({ running: true, timer: timer, drawEdges: drawEdges });
	};

	//strip force atlas options from component props


	ForceLink._stripOptions = function _stripOptions(props) {
		return (0, _assign2['default'])({}, props, { sigma: undefined });
	};

	ForceLink._propsChanged = function _propsChanged(prev, next) {
		for (var key in prev) {
			if (prev[key] !== next[key]) return true;
		}return false;
	};

	return ForceLink;
}(_react2['default'].Component);

ForceLink.defaultProps = {
	worker: true,
	linLogMode: true
};
ForceLink.propTypes = {
	barnesHutOptimize: require('react').PropTypes.bool,
	barnesHutTheta: require('react').PropTypes.number,
	adjustSizes: require('react').PropTypes.bool,
	iterationsPerRender: require('react').PropTypes.number,
	linLogMode: require('react').PropTypes.bool.isRequired,
	outboundAttractionDistribution: require('react').PropTypes.bool,
	edgeWeightInfluence: require('react').PropTypes.number,
	scalingRatio: require('react').PropTypes.number,
	strongGravityMode: require('react').PropTypes.bool,
	slowDown: require('react').PropTypes.number,
	gravity: require('react').PropTypes.number,
	alignNodeSiblings: require('react').PropTypes.bool,
	nodeSiblingsScale: require('react').PropTypes.number,
	nodeSiblingsAngleMin: require('react').PropTypes.number,
	worker: require('react').PropTypes.bool.isRequired,
	background: require('react').PropTypes.bool,
	easing: require('react').PropTypes.any,
	randomize: require('react').PropTypes.oneOf(['globally', 'locally', 'no']),
	timeout: require('react').PropTypes.number,
	sigma: require('react').PropTypes.any
};
exports['default'] = ForceLink;
module.exports = exports['default'];