'use strict';

exports.__esModule = true;

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _main = require('../sigma/main');

var _main2 = _interopRequireDefault(_main);

require('../sigma/parsers.json.js');

var _tools = require('./tools');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

// TODO: make a superclass for loaders??

/**

LoadJSON component, interface for parsers.json sigma plugin. Can be used within Sigma component.
Can be composed with other plugins: on load it mounts all child components (e.g. other sigma plugins). 
Child's componentWillMount should be used to enable plugins on loaded graph.

 @param {string} path   path to the JSON file
 @param {Function} onGraphLoaded        Optional callback for graph update

[see sigma plugin page for more details](https://github.com/jacomyal/sigma.js/tree/master/plugins/sigma.neo4j.cypher)

**/

var LoadJSON = function (_React$PureComponent) {
    (0, _inherits3['default'])(LoadJSON, _React$PureComponent);

    function LoadJSON(props) {
        (0, _classCallCheck3['default'])(this, LoadJSON);

        var _this = (0, _possibleConstructorReturn3['default'])(this, _React$PureComponent.call(this, props));

        _this.state = { loaded: false };
        _this.onLoad = _this._onLoad.bind(_this);
        return _this;
    }

    LoadJSON.prototype.componentDidMount = function componentDidMount() {
        this._load(this.props.path);
    };

    LoadJSON.prototype.componentWillReceiveProps = function componentWillReceiveProps(props) {
        // reload only if path changes
        if (this.props.path !== props.path) {
            this.setState({ loaded: false });
            this._load(props.path);
        }
    };

    LoadJSON.prototype.render = function render() {
        if (!this.state.loaded) return null;
        return _react2['default'].createElement(
            'div',
            null,
            (0, _tools.embedProps)(this.props.children, { sigma: this.props.sigma })
        );
    };

    LoadJSON.prototype._load = function _load(url) {
        _main2['default'].parsers.json(this.props.path, this.props.sigma, this.onLoad);
    };

    LoadJSON.prototype._onLoad = function _onLoad() {
        if (this.props.sigma) this.props.sigma.refresh();
        this.setState({ loaded: true });
        if (this.props.onGraphLoaded) return this.props.onGraphLoaded();
    };

    return LoadJSON;
}(_react2['default'].PureComponent);

LoadJSON.propTypes = {
    path: require('react').PropTypes.string.isRequired,
    onGraphLoaded: require('react').PropTypes.func,
    children: require('react').PropTypes.any,
    sigma: require('react').PropTypes.any
};
exports['default'] = LoadJSON;
module.exports = exports['default'];