'use strict';

exports.__esModule = true;

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _main = require('../sigma/main');

var _main2 = _interopRequireDefault(_main);

require('../sigma/plugins.animate');

require('../sigma/layout.noverlap');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

/**

NOverlap component, starts noverlap sigma plugin once component is mounted.
It supposes that sigma graph is already in place, therefore component should not be
mounted while graph is unavailable. It can be used within Sigma component if graph is
preloaded, or within loader component, like LoadJSON.

@param {number} [nodeMargin=5]    additional minimum space to apply around each and every node
@param {number} [scaleNodes=1.2]  multiplier,  larger nodes will have more space around
@param {number} [gridSize=20]   number of rows and columns to use when dividing the nodes up into cell
@param {number} [permittedExpansion=1.1]  maximum ratio to apply to the bounding box
@param {number} speed     larger value increases the speed at the cost of precision
@param {number} maxIterations  iterations to run the algorithm for before stopping it
@param {number} easing     camera easing type for camera transition
@param {number} duration     duration of the transition for the easing method

It accepts all the parameters of sigma.layout.noverlap plugin described on its github page:
[see sigma plugin page for more details](https://github.com/jacomyal/sigma.js/tree/master/plugins/sigma.layout.noverlap)

@example
<Sigma graph={data}>
 <NOverlap gridSize={10} maxIterations={100}/>
</Sigma>

**/

var NOverlap = function (_React$Component) {
	(0, _inherits3['default'])(NOverlap, _React$Component);

	function NOverlap(props) {
		(0, _classCallCheck3['default'])(this, NOverlap);

		var _this = (0, _possibleConstructorReturn3['default'])(this, _React$Component.call(this, props));

		_this.render = function () {
			return null;
		};

		_this.state = { running: false };
		return _this;
	}

	NOverlap.prototype.componentDidMount = function componentDidMount() {
		this._refreshGraph();
	};

	NOverlap.prototype.componentDidUpdate = function componentDidUpdate(prevProps, prevState) {
		if (prevState.running && !this.state.running) {
			if (this.props.sigma) this.props.sigma.settings({ drawEdges: prevState.drawEdges || true });
			if (this.props.sigma) this.props.sigma.refresh();
		}
	};

	NOverlap.prototype._refreshGraph = function _refreshGraph() {
		var _this2 = this;

		var s = this.props.sigma;
		if (!_main2['default'] || !s) return;

		var drawEdges = s.settings("drawEdges");
		if (s.graph.edges().length > 1000) s.settings({ drawEdges: false });

		var listener = s.configNoverlap(this._stripOptions(this.props));

		listener.bind('stop', function () {
			_this2.setState({ running: false });
		});

		this.setState({ running: true, drawEdges: drawEdges });

		s.startNoverlap();
	};

	//strip noverlap options from component props


	NOverlap.prototype._stripOptions = function _stripOptions(props) {
		return (0, _assign2['default'])({}, props, { sigma: undefined });
	};

	return NOverlap;
}(_react2['default'].Component);

NOverlap.propTypes = {
	nodes: require('react').PropTypes.arrayOf(require('react').PropTypes.any),
	nodeMargin: require('react').PropTypes.number,
	scaleNodes: require('react').PropTypes.number,
	gridSize: require('react').PropTypes.number,
	permittedExpansion: require('react').PropTypes.number,
	speed: require('react').PropTypes.number,
	maxIterations: require('react').PropTypes.number,
	easing: require('react').PropTypes.any,
	duration: require('react').PropTypes.number,
	sigma: require('react').PropTypes.any
};
exports['default'] = NOverlap;
module.exports = exports['default'];