'use strict';

exports.__esModule = true;

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _main = require('../sigma/main');

var _main2 = _interopRequireDefault(_main);

require('../sigma/parsers.json.js');

require('../sigma/neo4j.cypher');

var _NeoGraphItemsProducers = require('./NeoGraphItemsProducers');

var _NeoGraphItemsProducers2 = _interopRequireDefault(_NeoGraphItemsProducers);

var _tools = require('./tools');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

/**

NeoCypher component, interface for neo4j.cypher sigma plugin. Can be used within Sigma component.
Can be composed with other plugins: on load it mounts all child components (e.g. other sigma plugins). 
Child's componentWillMount should be used to enable plugins on loaded graph.

 @param {string} url    Neo4j instance REST API URL
 @param {string} user    Neo4j instance REST API user
 @param {string} password    Neo4j instance REST API password
 @param {string} query    Neo4j cypher query
 @param {NeoGraphItemsProducers} producers   Optional transformer for creating Sigma nodes and edges, 
                                    instance compatible with NeoGraphItemsProducers
 @param {Function} onGraphLoaded        Optional callback for graph update

[see sigma plugin page for more details](https://github.com/jacomyal/sigma.js/tree/master/plugins/sigma.neo4j.cypher)

**/

var NeoCypher = function (_React$PureComponent) {
    (0, _inherits3['default'])(NeoCypher, _React$PureComponent);

    function NeoCypher(props) {
        (0, _classCallCheck3['default'])(this, NeoCypher);

        var _this = (0, _possibleConstructorReturn3['default'])(this, _React$PureComponent.call(this, props));

        _this.state = { loaded: false };
        _this.onLoad = _this._onLoad.bind(_this);
        return _this;
    }

    NeoCypher.prototype.componentDidMount = function componentDidMount() {
        this._runQuery(this.props.query);
    };

    NeoCypher.prototype.componentWillUpdate = function componentWillUpdate(props) {
        // suppose url, user or password won't change for sigma instance, as well as sigma instance itself
        if (this.props.query !== props.query) {
            this.setState({ loaded: false });
            this._runQuery(props.query);
        }
    };

    NeoCypher.prototype.render = function render() {
        if (!this.state.loaded) return null;
        return _react2['default'].createElement(
            'div',
            null,
            (0, _tools.embedProps)(this.props.children, { sigma: this.props.sigma })
        );
    };

    NeoCypher.prototype._runQuery = function _runQuery(query) {
        // TODO: add exception handling capability to Sigma Neo4j plugin
        _main2['default'].neo4j.cypher({ url: this.props.url, user: this.props.user, password: this.props.password }, query, this.props.sigma, this.onLoad, this.props.producers);
    };

    NeoCypher.prototype._onLoad = function _onLoad() {
        this.setState({ loaded: true });
        if (this.props.sigma) this.props.sigma.refresh();
        if (this.props.onGraphLoaded) return this.props.onGraphLoaded();
    };

    return NeoCypher;
}(_react2['default'].PureComponent);

NeoCypher.defaultProps = {
    producers: new _NeoGraphItemsProducers2['default']()
};
NeoCypher.propTypes = {
    url: require('react').PropTypes.string.isRequired,
    user: require('react').PropTypes.string.isRequired,
    password: require('react').PropTypes.string.isRequired,
    query: require('react').PropTypes.string.isRequired,
    producers: require('react').PropTypes.any.isRequired,
    onGraphLoaded: require('react').PropTypes.func,
    children: require('react').PropTypes.any,
    sigma: require('react').PropTypes.any
};
exports['default'] = NeoCypher;
module.exports = exports['default'];