"use strict";

exports.__esModule = true;

var _classCallCheck2 = require("babel-runtime/helpers/classCallCheck");

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var palette = ["#5DA5DA", "#60BD68", "#B2912F", "#F15854", "#DECF3F", "#FAA43A", "#B276B2", "#F17CB0", "#4D4D4D"];

/*
	Default node and edge transformation for NeoCypher,
	class has 2 functions: node() and edge() which transform data from Neo4j format into Sigma.

	Also it iterates colors assignments from palette based on node.label and edge.type.
*/

var NeoGraphItemsProducers = function () {
	function NeoGraphItemsProducers() {
		(0, _classCallCheck3["default"])(this, NeoGraphItemsProducers);

		this._currentColor = 0;
		this._colorsMap = {};
	}

	NeoGraphItemsProducers.prototype.node = function node(_node) {
		return {
			id: _node.id,
			label: _node.properties.name,
			x: Math.random(),
			y: Math.random(),
			size: 1,
			color: this.colorsMap(_node.labels[0]),
			neo4j_labels: _node.labels,
			neo4j_data: _node.properties
		};
	};

	NeoGraphItemsProducers.prototype.edge = function edge(_edge) {
		return {
			id: _edge.id,
			label: _edge.type,
			source: _edge.startNode,
			target: _edge.endNode,
			color: this.colorsMap(_edge.type),
			neo4j_type: _edge.type,
			neo4j_data: _edge.properties
		};
	};

	NeoGraphItemsProducers.prototype.colorsMap = function colorsMap(label) {
		var color = this._colorsMap[label];
		if (!color) {
			color = palette[this._currentColor++ % palette.length];
			this._colorsMap[label] = color;
		}
		return color;
	};

	return NeoGraphItemsProducers;
}();

exports["default"] = NeoGraphItemsProducers;
module.exports = exports["default"];